@@ -8,6 +8,9 @@
 #' style file is required in the final html document.
 #' Use [math_to_rd] for embedding math into R documentation (`.rd`) pages.
 #'
+#' Refer to the upstream [katex support table](https://katex.org/docs/support_table.html) for
+#' the full list of supported tex functions that can be rendered to html using katex.
+#'
 #' By default, [katex_html] returns a mix of HTML for visual rendering and includes
 #' MathML for accessibility. To only get html, pass `output="html"` in the extra options,
 #' see also the [katex documentation](https://katex.org/docs/options.html).
@@ -45,8 +48,8 @@ katex_html <- function(tex, displayMode = TRUE, ..., include_css = FALSE, previe
     viewer(tmp)
   }
   if(isTRUE(include_css))
-    html <- paste('<link rel="stylesheet" type="text/css" href="https://cdn.jsdelivr.net/npm/katex@0.13.11/dist/katex.min.css">', html, sep = '\n')
-  html
+    html <- paste('<link rel="stylesheet" type="text/css" href="https://cdn.jsdelivr.net/npm/katex@0.13.11/dist/katex.min.css" data-external="1">', html, sep = '\n')
+  structure(html, class = c('html', 'character'))
 }
 
 #' @export
@@ -83,7 +86,7 @@ template <- '<!DOCTYPE html>
 <html>
   <head>
     <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/katex@0.13.11/dist/katex.min.css">
+    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/katex@0.13.11/dist/katex.min.css" data-external="1">
   </head>
   <body>
   {{math}}
